@@ -35,6 +35,7 @@
 #include <crawl.h>
 #include <webbase.h>
 #include <webbase_create.h>
+#include <WebbaseDl.h>
 
 #define MAX_OPTIONS 100
 #define APPLICATION_OPTIONS		0x8000000
@@ -117,8 +118,14 @@ void finish()
   exit(0);
 }
 
+extern "C" {
+void* hooksmifluz_init();
+}
+
 static void init(int argc, char** argv)
 {
+  WebbaseDl::Instance()->Parse(argc, argv);
+  
   static struct option long_options[MAX_OPTIONS + 1] =
   {
     /* These options set a flag. */
@@ -143,13 +150,14 @@ static void init(int argc, char** argv)
 
   getopt_merge(long_options, crawl_options(long_options));
 
+  opterr = 0;
   optind = 0;
   while(1) {
     /* `getopt_long' stores the option index here. */
     int option_index = 0;
     int c;
 
-    c = getopt_long_only(argc, argv, "", long_options, &option_index);
+    c = getopt_long_only(argc, argv, "-", long_options, &option_index);
 
     /* Detect the end of the options. */
     if (c == -1)
@@ -178,9 +186,6 @@ static void init(int argc, char** argv)
 	} else if(!strcmp(long_options[option_index].name, "")) {
 	}
 	break;
-      default:
-	fprintf(stderr, "option parse error %c, 0x%x\n", c & 0xff, c);
-	exit(1);
       }
   }
 
