@@ -28,9 +28,7 @@
 #include <robots.h>
 #include <cookies.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+class WebbaseHook;
 
 #define CRAWL_PARAMS_CANDIDATE_LIMIT	200
 
@@ -48,6 +46,7 @@ typedef struct crawl_params {
   int update_rebuild;
   int candidate_limit;
   int sticky;
+  WebbaseHook* hook;
 } crawl_params_t;
 
 struct option* crawl_options(struct option options[]);
@@ -68,8 +67,4 @@ void hp_print_externals(crawl_params_t* params, char* where);
 void hp_remove_unloaded(crawl_params_t* params, char* url);
 webbase_url_t* crawl_touch(crawl_params_t* params, char* url);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _crawl_h */
