@@ -22,10 +22,6 @@
 #include <mysql.h>
 #include <mysqld_error.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /*
  * Secure version of the corresponding mysql call
  */
@@ -45,9 +41,5 @@ int sql_select(MYSQL* mysql, char* header, char* query, sql_select_callback call
 int sql_select_value(MYSQL* mysql, char* query, char* value, int value_size);
 void sqlutil_verbose(int level);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _sqlutil_h */
 
